@@ -1,11 +1,15 @@
-/******************************************************************************
- *
- * Copyright (c) 2019, the Perspective Authors.
- *
- * This file is part of the Perspective library, distributed under the terms of
- * the Apache License 2.0.  The full license can be found in the LICENSE file.
- *
- */
+// ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
+// ┃ ██████ ██████ ██████       █      █      █      █      █ █▄  ▀███ █       ┃
+// ┃ ▄▄▄▄▄█ █▄▄▄▄▄ ▄▄▄▄▄█  ▀▀▀▀▀█▀▀▀▀▀ █ ▀▀▀▀▀█ ████████▌▐███ ███▄  ▀█ █ ▀▀▀▀▀ ┃
+// ┃ █▀▀▀▀▀ █▀▀▀▀▀ █▀██▀▀ ▄▄▄▄▄ █ ▄▄▄▄▄█ ▄▄▄▄▄█ ████████▌▐███ █████▄   █ ▄▄▄▄▄ ┃
+// ┃ █      ██████ █  ▀█▄       █ ██████      █      ███▌▐███ ███████▄ █       ┃
+// ┣━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┫
+// ┃ Copyright (c) 2017, the Perspective Authors.                              ┃
+// ┃ ╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌ ┃
+// ┃ This file is part of the Perspective library, distributed under the terms ┃
+// ┃ of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). ┃
+// ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛
+
 #ifdef PSP_ENABLE_PYTHON
 #include <perspective/python/fill.h>
 #include <perspective/python/numpy.h>
@@ -15,12 +19,13 @@ using namespace perspective;
 namespace perspective {
 namespace numpy {
 
-    const std::vector<std::string> NumpyLoader::DATE_UNITS
-        = {"[D]", "[W]", "[M]", "[Y]"};
+    const std::vector<std::string> NumpyLoader::DATE_UNITS = {
+        "[D]", "[W]", "[M]", "[Y]"
+    };
 
-    NumpyLoader::NumpyLoader(t_val accessor)
-        : m_init(false)
-        , m_accessor(accessor) {}
+    NumpyLoader::NumpyLoader(t_val accessor) :
+        m_init(false),
+        m_accessor(accessor) {}
 
     NumpyLoader::~NumpyLoader() {}
 
@@ -32,16 +37,16 @@ namespace numpy {
     }
 
     std::vector<t_dtype>
-    NumpyLoader::reconcile_dtypes(
-        const std::vector<t_dtype>& inferred_types) const {
+    NumpyLoader::reconcile_dtypes(const std::vector<t_dtype>& inferred_types
+    ) const {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         std::uint32_t num_columns = m_names.size();
         std::vector<t_dtype> reconciled_types(num_columns);
 
         // Get numpy dtypes as string so we can tell the difference between
         // dates and datetimes
-        std::vector<std::string> str_dtypes
-            = m_accessor.attr("types")().cast<std::vector<std::string>>();
+        std::vector<std::string> str_dtypes =
+            m_accessor.attr("types")().cast<std::vector<std::string>>();
 
         for (auto i = 0; i < num_columns; ++i) {
             std::string numpy_type_as_string = str_dtypes[i];
@@ -88,9 +93,14 @@ namespace numpy {
     }
 
     void
-    NumpyLoader::fill_table(t_data_table& tbl, const t_schema& input_schema,
-        const std::string& index, std::uint32_t offset, std::uint32_t limit,
-        bool is_update) {
+    NumpyLoader::fill_table(
+        t_data_table& tbl,
+        const t_schema& input_schema,
+        const std::string& index,
+        std::uint32_t offset,
+        std::uint32_t limit,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         bool implicit_index = false;
         std::vector<std::string> col_names(input_schema.columns());
@@ -102,10 +112,11 @@ namespace numpy {
 
             if (name == "__INDEX__") {
                 implicit_index = true;
-                std::shared_ptr<t_column> pkey_col_sptr
-                    = tbl.add_column_sptr("psp_pkey", type, true);
+                std::shared_ptr<t_column> pkey_col_sptr =
+                    tbl.add_column_sptr("psp_pkey", type, true);
                 fill_column(
-                    tbl, pkey_col_sptr, "__INDEX__", type, cidx, is_update);
+                    tbl, pkey_col_sptr, "__INDEX__", type, cidx, is_update
+                );
                 tbl.clone_column("psp_pkey", "psp_okey");
                 continue;
             }
@@ -124,9 +135,11 @@ namespace numpy {
 
                 for (std::uint32_t ridx = 0; ridx < tbl.size(); ++ridx) {
                     key_col->set_nth<std::int32_t>(
-                        ridx, (ridx + offset) % limit);
+                        ridx, (ridx + offset) % limit
+                    );
                     okey_col->set_nth<std::int32_t>(
-                        ridx, (ridx + offset) % limit);
+                        ridx, (ridx + offset) % limit
+                    );
                 }
             } else {
                 tbl.clone_column(index, "psp_pkey");
@@ -136,9 +149,14 @@ namespace numpy {
     }
 
     void
-    NumpyLoader::fill_column(t_data_table& tbl, std::shared_ptr<t_column> col,
-        const std::string& name, t_dtype type, std::uint32_t cidx,
-        bool is_update) {
+    NumpyLoader::fill_column(
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
 
         // Use name index instead of column index - prevents off-by-one errors
@@ -157,8 +175,8 @@ namespace numpy {
 
         py::dict source = m_accessor.attr("_get_numpy_column")(name);
         py::array array = source["array"].cast<py::array>();
-        py::array_t<std::uint64_t> mask
-            = source["mask"].cast<py::array_t<std::uint64_t>>();
+        py::array_t<std::uint64_t> mask =
+            source["mask"].cast<py::array_t<std::uint64_t>>();
         std::uint64_t* mask_ptr = (std::uint64_t*)mask.data();
         std::size_t mask_size = mask.size();
 
@@ -166,7 +184,8 @@ namespace numpy {
         // it to an object.
         if (array.dtype().kind() == 'O') {
             fill_column_iter(
-                array, tbl, col, name, DTYPE_OBJECT, type, cidx, is_update);
+                array, tbl, col, name, DTYPE_OBJECT, type, cidx, is_update
+            );
             return;
         }
 
@@ -174,7 +193,8 @@ namespace numpy {
         // need to be read as int64
         if (type == DTYPE_TIME || type == DTYPE_DATE) {
             fill_column_iter(
-                array, tbl, col, name, np_dtype, type, cidx, is_update);
+                array, tbl, col, name, np_dtype, type, cidx, is_update
+            );
             fill_validity_map(col, mask_ptr, mask_size, is_update);
             return;
         }
@@ -195,9 +215,8 @@ namespace numpy {
          * data or schema, then updated with a numpy array. In these cases, the
          * `t_dtype` of the Table supercedes the array dtype.
          */
-        bool should_iter
-            = (np_dtype == DTYPE_INT64
-                  && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
+        bool should_iter = (np_dtype == DTYPE_INT64
+                            && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
             || (np_dtype == DTYPE_INT32
                 && (type == DTYPE_INT64 || type == DTYPE_FLOAT64))
             || (np_dtype == DTYPE_FLOAT64
@@ -208,7 +227,8 @@ namespace numpy {
         if (should_iter) {
             // Skip straight to numeric fill
             fill_numeric_iter(
-                array, tbl, col, name, np_dtype, type, cidx, is_update);
+                array, tbl, col, name, np_dtype, type, cidx, is_update
+            );
             return;
         }
 
@@ -217,7 +237,8 @@ namespace numpy {
         // Iterate if copy is not supported for the numpy array
         if (copy_status == t_fill_status::FILL_FAIL) {
             fill_column_iter(
-                array, tbl, col, name, np_dtype, type, cidx, is_update);
+                array, tbl, col, name, np_dtype, type, cidx, is_update
+            );
         }
 
         // Fill validity map using null mask
@@ -226,9 +247,15 @@ namespace numpy {
 
     template <typename T>
     void
-    NumpyLoader::fill_object_iter(t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter(
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -251,9 +278,15 @@ namespace numpy {
     // promotion logic
     template <>
     void
-    NumpyLoader::fill_object_iter<std::int32_t>(t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<std::int32_t>(
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -271,18 +304,21 @@ namespace numpy {
             double fval = item.cast<double>();
             if (!is_update && (fval > 2147483647 || fval < -2147483648)) {
                 binding::WARN(
-                    "Promoting column `%s` to float from int32", name);
+                    "Promoting column `%s` to float from int32", name
+                );
                 tbl.promote_column(name, DTYPE_FLOAT64, i, true);
                 col = tbl.get_column(name);
                 type = DTYPE_FLOAT64;
                 col->set_nth(i, fval);
             } else if (!is_update && isnan(fval)) {
                 binding::WARN(
-                    "Promoting column `%s` to string from int32", name);
+                    "Promoting column `%s` to string from int32", name
+                );
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
-                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update);
+                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update
+                );
                 return;
             } else {
                 col->set_nth(i, static_cast<std::int32_t>(fval));
@@ -292,9 +328,15 @@ namespace numpy {
 
     template <>
     void
-    NumpyLoader::fill_object_iter<std::int64_t>(t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<std::int64_t>(
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -312,11 +354,13 @@ namespace numpy {
             double fval = item.cast<double>();
             if (isnan(fval)) {
                 binding::WARN(
-                    "Promoting column `%s` to string from int64", name);
+                    "Promoting column `%s` to string from int64", name
+                );
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
-                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update);
+                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update
+                );
                 return;
             } else {
                 col->set_nth(i, static_cast<std::int64_t>(fval));
@@ -326,9 +370,15 @@ namespace numpy {
 
     template <>
     void
-    NumpyLoader::fill_object_iter<double>(t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_object_iter<double>(
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         t_uindex nrows = col->size();
 
         for (auto i = 0; i < nrows; ++i) {
@@ -347,11 +397,13 @@ namespace numpy {
             bool is_numpy_nan = is_float && npy_isnan(item.cast<double>());
             if (!is_float || is_numpy_nan) {
                 binding::WARN(
-                    "Promoting column `%s` to string from float64", name);
+                    "Promoting column `%s` to string from float64", name
+                );
                 tbl.promote_column(name, DTYPE_STR, i, false);
                 col = tbl.get_column(name);
                 fill_object_iter<std::string>(
-                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update);
+                    tbl, col, name, np_dtype, DTYPE_STR, cidx, is_update
+                );
                 return;
             }
             col->set_nth(i, item.cast<double>());
@@ -360,9 +412,16 @@ namespace numpy {
 
     // Must be below `fill_object_iter` explicit instantiations.
     void
-    NumpyLoader::fill_column_iter(const py::array& array, t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_column_iter(
+        const py::array& array,
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         // Numpy arrays are guaranteed to be continous and valid by the time
         // they enter this block, but if they're of dtype object, then we need
@@ -373,10 +432,12 @@ namespace numpy {
                 // integer timestamps in ms or s since epoch
                 if (np_dtype != DTYPE_TIME) {
                     fill_object_iter<std::int64_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                 } else {
                     fill_datetime_iter(
-                        array, tbl, col, name, np_dtype, type, cidx, is_update);
+                        array, tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                 }
             } break;
             case DTYPE_DATE: {
@@ -387,22 +448,26 @@ namespace numpy {
             case DTYPE_BOOL: {
                 if (np_dtype == DTYPE_OBJECT) {
                     fill_object_iter<bool>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                 } else {
                     fill_bool_iter(
-                        array, tbl, col, name, np_dtype, type, cidx, is_update);
+                        array, tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                 }
             } break;
             case DTYPE_STR: {
                 // dtype `U`
                 fill_object_iter<std::string>(
-                    tbl, col, name, np_dtype, type, cidx, is_update);
+                    tbl, col, name, np_dtype, type, cidx, is_update
+                );
             } break;
             default: {
                 // dtype `i/u/f` - fill_numeric_iter checks again for
                 // `dtype=object`
                 fill_numeric_iter(
-                    array, tbl, col, name, np_dtype, type, cidx, is_update);
+                    array, tbl, col, name, np_dtype, type, cidx, is_update
+                );
                 break;
             }
         }
@@ -410,9 +475,16 @@ namespace numpy {
 
     // `array.dtype=datetime64[ns/us/ms/s]`
     void
-    NumpyLoader::fill_datetime_iter(const py::array& array, t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_datetime_iter(
+        const py::array& array,
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
@@ -420,16 +492,21 @@ namespace numpy {
         double* ptr = (double*)array.data();
 
         for (auto i = 0; i < nrows; ++i) {
-            std::int64_t item
-                = ptr[i]; // Perspective stores datetimes using int64
+            std::int64_t item =
+                ptr[i]; // Perspective stores datetimes using int64
             col->set_nth(i, item);
         }
     }
 
     void
-    NumpyLoader::fill_date_iter(std::shared_ptr<t_column> col,
-        const std::string& name, t_dtype np_dtype, t_dtype type,
-        std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_date_iter(
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
@@ -445,19 +522,29 @@ namespace numpy {
                 continue;
             }
 
-            auto date_components
-                = item.cast<std::map<std::string, std::int32_t>>();
+            auto date_components =
+                item.cast<std::map<std::string, std::int32_t>>();
             // date_components["month"] should be [0-11]
-            t_date dt = t_date(date_components["year"],
-                date_components["month"], date_components["day"]);
+            t_date dt = t_date(
+                date_components["year"],
+                date_components["month"],
+                date_components["day"]
+            );
             col->set_nth(i, dt);
         }
     }
 
     void
-    NumpyLoader::fill_bool_iter(const py::array& array, t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_bool_iter(
+        const py::array& array,
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
 
@@ -465,7 +552,8 @@ namespace numpy {
         if (np_dtype == DTYPE_OBJECT) {
             // handle object arrays
             fill_object_iter<bool>(
-                tbl, col, name, np_dtype, type, cidx, is_update);
+                tbl, col, name, np_dtype, type, cidx, is_update
+            );
         } else {
             bool* ptr = (bool*)array.data();
 
@@ -477,18 +565,25 @@ namespace numpy {
     }
 
     void
-    NumpyLoader::fill_numeric_iter(const py::array& array, t_data_table& tbl,
-        std::shared_ptr<t_column> col, const std::string& name,
-        t_dtype np_dtype, t_dtype type, std::uint32_t cidx, bool is_update) {
+    NumpyLoader::fill_numeric_iter(
+        const py::array& array,
+        t_data_table& tbl,
+        std::shared_ptr<t_column> col,
+        const std::string& name,
+        t_dtype np_dtype,
+        t_dtype type,
+        std::uint32_t cidx,
+        bool is_update
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         t_uindex nrows = col->size();
         const void* ptr = array.data();
 
         // We fill by object when `np_dtype`=object, or if there are type
         // mismatches between `np_dtype` and `type`.
-        bool types_mismatched
-            = (np_dtype == DTYPE_INT64
-                  && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
+        bool types_mismatched =
+            (np_dtype == DTYPE_INT64
+             && (type == DTYPE_INT32 || type == DTYPE_FLOAT64))
             || (np_dtype == DTYPE_INT32
                 && (type == DTYPE_INT64 || type == DTYPE_FLOAT64))
             || (np_dtype == DTYPE_FLOAT64
@@ -500,57 +595,69 @@ namespace numpy {
             switch (type) {
                 case DTYPE_UINT8: {
                     fill_object_iter<std::uint8_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_UINT16: {
                     fill_object_iter<std::uint16_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_UINT32: {
                     fill_object_iter<std::uint32_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_UINT64: {
                     fill_object_iter<std::uint64_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_INT8: {
                     fill_object_iter<std::int8_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_INT16: {
                     fill_object_iter<std::int16_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_INT32: {
                     fill_object_iter<std::int32_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_INT64: {
                     fill_object_iter<std::int64_t>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_FLOAT32: {
                     fill_object_iter<float>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 case DTYPE_FLOAT64: {
                     fill_object_iter<double>(
-                        tbl, col, name, np_dtype, type, cidx, is_update);
+                        tbl, col, name, np_dtype, type, cidx, is_update
+                    );
                     return;
                 } break;
                 default:
-                    PSP_COMPLAIN_AND_ABORT("Unable to fill non-numeric column `"
-                        + name + "` in `fill_numeric_iter`.")
+                    PSP_COMPLAIN_AND_ABORT(
+                        "Unable to fill non-numeric column `" + name
+                        + "` in `fill_numeric_iter`."
+                    )
             }
         }
 
@@ -609,9 +716,13 @@ namespace numpy {
      * Copy numpy arrays into columns
      */
     t_fill_status
-    NumpyLoader::try_copy_array(const py::array& src,
-        std::shared_ptr<t_column> dest, t_dtype np_dtype, t_dtype type,
-        const std::uint64_t offset) {
+    NumpyLoader::try_copy_array(
+        const py::array& src,
+        std::shared_ptr<t_column> dest,
+        t_dtype np_dtype,
+        t_dtype type,
+        const std::uint64_t offset
+    ) {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
         std::int64_t length = src.size();
 
@@ -656,8 +767,12 @@ namespace numpy {
     }
 
     void
-    NumpyLoader::fill_validity_map(std::shared_ptr<t_column> col,
-        std::uint64_t* mask_ptr, std::size_t mask_size, bool is_update) {
+    NumpyLoader::fill_validity_map(
+        std::shared_ptr<t_column> col,
+        std::uint64_t* mask_ptr,
+        std::size_t mask_size,
+        bool is_update
+    ) {
         // Validity map needs to be filled each time - None/np.nan/float('nan')
         // might not have been parsed correctly
         col->valid_raw_fill();
@@ -676,8 +791,11 @@ namespace numpy {
 
     template <typename T>
     void
-    copy_array_helper(const void* src, std::shared_ptr<t_column> dest,
-        const std::uint64_t offset) {
+    copy_array_helper(
+        const void* src,
+        std::shared_ptr<t_column> dest,
+        const std::uint64_t offset
+    ) {
         std::memcpy(dest->get_nth<T>(offset), src, dest->size() * sizeof(T));
     }
 
@@ -688,8 +806,8 @@ namespace numpy {
     std::vector<std::string>
     NumpyLoader::make_names() {
         auto data = m_accessor.attr("data")();
-        auto py_names
-            = m_accessor.attr("names")().cast<std::vector<std::string>>();
+        auto py_names =
+            m_accessor.attr("names")().cast<std::vector<std::string>>();
 
         // Match names to dataset - only keep names that are present in dataset.
         // The `m_names` variable is used internally to access the numpy arrays
@@ -719,8 +837,10 @@ namespace numpy {
             py::array array = py::array::ensure(data[py::str(name)]);
 
             if (!array) {
-                PSP_COMPLAIN_AND_ABORT("Perspective does not support the "
-                                       "mixing of ndarrays and lists.");
+                PSP_COMPLAIN_AND_ABORT(
+                    "Perspective does not support the "
+                    "mixing of ndarrays and lists."
+                );
             }
 
             // can't use isinstance on datetime/timedelta array, so check the
