@@ -1,10 +1,14 @@
-################################################################################
-#
-# Copyright (c) 2019, the Perspective Authors.
-#
-# This file is part of the Perspective library, distributed under the terms of
-# the Apache License 2.0.  The full license can be found in the LICENSE file.
-#
+#  ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
+#  ┃ ██████ ██████ ██████       █      █      █      █      █ █▄  ▀███ █       ┃
+#  ┃ ▄▄▄▄▄█ █▄▄▄▄▄ ▄▄▄▄▄█  ▀▀▀▀▀█▀▀▀▀▀ █ ▀▀▀▀▀█ ████████▌▐███ ███▄  ▀█ █ ▀▀▀▀▀ ┃
+#  ┃ █▀▀▀▀▀ █▀▀▀▀▀ █▀██▀▀ ▄▄▄▄▄ █ ▄▄▄▄▄█ ▄▄▄▄▄█ ████████▌▐███ █████▄   █ ▄▄▄▄▄ ┃
+#  ┃ █      ██████ █  ▀█▄       █ ██████      █      ███▌▐███ ███████▄ █       ┃
+#  ┣━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┫
+#  ┃ Copyright (c) 2017, the Perspective Authors.                              ┃
+#  ┃ ╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌ ┃
+#  ┃ This file is part of the Perspective library, distributed under the terms ┃
+#  ┃ of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). ┃
+#  ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛
 
 import numpy as np
 import pandas as pd
@@ -12,7 +16,6 @@ from perspective import PerspectiveViewer, Table
 
 
 class TestViewer:
-
     def test_viewer_get_table(self):
         table = Table({"a": [1, 2, 3]})
         viewer = PerspectiveViewer()
@@ -48,12 +51,7 @@ class TestViewer:
 
     def test_viewer_load_schema(self):
         viewer = PerspectiveViewer()
-        viewer.load({
-            "a": str,
-            "b": int,
-            "c": bool,
-            "d": str
-        })
+        viewer.load({"a": str, "b": int, "c": bool, "d": str})
         for col in viewer.columns:
             assert col in ["a", "b", "c", "d"]
 
@@ -74,12 +72,12 @@ class TestViewer:
 
     def test_viewer_load_clears_state(self):
         table = Table({"a": [1, 2, 3]})
-        viewer = PerspectiveViewer(theme="Material Dark", group_by=["a"])
+        viewer = PerspectiveViewer(theme="Pro Dark", group_by=["a"])
         viewer.load(table)
         assert viewer.group_by == ["a"]
         viewer.load({"b": [1, 2, 3]})
         assert viewer.group_by == []
-        assert viewer.theme == "Material Dark"  # should not break UI
+        assert viewer.theme == "Pro Dark"  # should not break UI
 
     def test_viewer_load_np(self):
         table = Table({"a": np.arange(1, 100)})
@@ -116,9 +114,7 @@ class TestViewer:
         viewer.update({"a": [4, 5, 6]})
         assert table.size() == 6
         assert viewer.table.size() == 6
-        assert viewer.table.view().to_dict() == {
-            "a": [1, 2, 3, 4, 5, 6]
-        }
+        assert viewer.table.view().to_dict() == {"a": [1, 2, 3, 4, 5, 6]}
 
     def test_viewer_update_list(self):
         table = Table({"a": [1, 2, 3]})
@@ -127,9 +123,7 @@ class TestViewer:
         viewer.update([{"a": 4}, {"a": 5}, {"a": 6}])
         assert table.size() == 6
         assert viewer.table.size() == 6
-        assert viewer.table.view().to_dict() == {
-            "a": [1, 2, 3, 4, 5, 6]
-        }
+        assert viewer.table.view().to_dict() == {"a": [1, 2, 3, 4, 5, 6]}
 
     def test_viewer_update_df(self):
         table = Table({"a": [1, 2, 3]})
@@ -138,9 +132,7 @@ class TestViewer:
         viewer.update(pd.DataFrame({"a": [4, 5, 6]}))
         assert table.size() == 6
         assert viewer.table.size() == 6
-        assert viewer.table.view().to_dict() == {
-            "a": [1, 2, 3, 4, 5, 6]
-        }
+        assert viewer.table.view().to_dict() == {"a": [1, 2, 3, 4, 5, 6]}
 
     def test_viewer_update_dict_partial(self):
         table = Table({"a": [1, 2, 3], "b": [5, 6, 7]}, index="a")
@@ -149,10 +141,7 @@ class TestViewer:
         viewer.update({"a": [1, 2, 3], "b": [8, 9, 10]})
         assert table.size() == 3
         assert viewer.table.size() == 3
-        assert viewer.table.view().to_dict() == {
-            "a": [1, 2, 3],
-            "b": [8, 9, 10]
-        }
+        assert viewer.table.view().to_dict() == {"a": [1, 2, 3], "b": [8, 9, 10]}
 
     # clear
 
@@ -162,9 +151,7 @@ class TestViewer:
         viewer.load(table)
         viewer.clear()
         assert viewer.table.size() == 0
-        assert viewer.table.schema() == {
-            "a": int
-        }
+        assert viewer.table.schema() == {"a": int}
 
     # replace
 
@@ -174,12 +161,8 @@ class TestViewer:
         viewer.load(table)
         viewer.replace({"a": [4, 5, 6]})
         assert viewer.table.size() == 3
-        assert viewer.table.schema() == {
-            "a": int
-        }
-        assert viewer.table.view().to_dict() == {
-            "a": [4, 5, 6]
-        }
+        assert viewer.table.schema() == {"a": int}
+        assert viewer.table.view().to_dict() == {"a": [4, 5, 6]}
 
     # reset
 
@@ -215,11 +198,7 @@ class TestViewer:
 
     def test_save_restore(self):
         table = Table({"a": [1, 2, 3]})
-        viewer = PerspectiveViewer(
-            plugin="X Bar",
-            filter=[["a", "==", 2]],
-            expressions=['"a" * 2']
-        )
+        viewer = PerspectiveViewer(plugin="X Bar", filter=[["a", "==", 2]], expressions={'"a" * 2': '"a" * 2'})
         viewer.load(table)
 
         # Save config
@@ -228,31 +207,25 @@ class TestViewer:
         assert config["filter"] == [["a", "==", 2]]
         assert viewer.plugin == "X Bar"
         assert config["plugin"] == "X Bar"
-        assert config["expressions"] == ['"a" * 2']
+        assert config["expressions"] == {'"a" * 2': '"a" * 2'}
 
         # reset configuration
         viewer.reset()
         assert viewer.plugin == "Datagrid"
         assert viewer.filter == []
-        assert viewer.expressions == []
+        assert viewer.expressions == {}
 
         # restore configuration
         viewer.restore(**config)
         assert viewer.filter == [["a", "==", 2]]
         assert viewer.plugin == "X Bar"
-        assert viewer.expressions == ['"a" * 2']
+        assert viewer.expressions == {'"a" * 2': '"a" * 2'}
 
     def test_save_restore_plugin_config(self):
         viewer = PerspectiveViewer(plugin="Datagrid", plugin_config={"columns": {"a": {"fixed": 4}}})
         config = viewer.save()
 
-        assert config["plugin_config"] == {
-            "columns": {
-                "a": {
-                    "fixed": 4
-                }
-            }
-        }
+        assert config["plugin_config"] == {"columns": {"a": {"fixed": 4}}}
 
         viewer.reset()
         assert viewer.plugin_config == {}
