@@ -59,6 +59,7 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         "theme",
         "settings",
         "title",
+        "version",
     )
 
     def __init__(
@@ -75,6 +76,8 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         settings=True,
         theme=None,
         title=None,
+        # ignored, here for restore compatibility
+        version=None,
     ):
         """Initialize an instance of `PerspectiveViewer` with the given viewer
         configuration.  Do not pass a `Table` or data into the constructor -
@@ -106,6 +109,9 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
             settings(:obj:`bool`): Whether the perspective query settings
                 panel should be open.
             theme (:obj:`str`): The color theme to use.
+            version (:obj:`str`): The version this configuration is restored from.
+                This should only be used when restoring a configuration,
+                and should not be set manually.
 
         Examples:
             >>> viewer = PerspectiveViewer(
@@ -113,7 +119,7 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
             ...     group_by=["a"],
             ...     sort=[["b", "desc"]],
             ...     filter=[["a", ">", 1]],
-            ...     expressions=["// new column \n \"Sales\" + \"Profit\""]
+            ...     expressions=["\"a\" + 100"]
             ... )
         """
 
@@ -134,7 +140,7 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         self.aggregates = validate_aggregates(aggregates) or {}
         self.sort = validate_sort(sort) or []
         self.filter = validate_filter(filter) or []
-        self.expressions = validate_expressions(expressions) or []
+        self.expressions = validate_expressions(expressions) or {}
         self.plugin_config = validate_plugin_config(plugin_config) or {}
         self.settings = settings
         self.theme = theme
@@ -269,7 +275,7 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         self.split_by = []
         self.filter = []
         self.sort = []
-        self.expressions = []
+        self.expressions = {}
         self.aggregates = {}
         self.columns = []
         self.plugin = "Datagrid"
